"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTestCoverageReport = void 0;
const chalk_1 = __importDefault(require("chalk"));
const getTestCoverage_1 = require("../getTestCoverage");
function getTestCoverageReport(testCoverage, coverageThreshold) {
    const entries = [];
    if (testCoverage.passed) {
        const coverageSum = getTestCoverage_1.coverageTypes.reduce((all, type) => all + testCoverage.summary[type].pct, 0);
        const avgCoverage = Math.round((coverageSum * 100) / 4) / 100;
        entries.push(`Test coverage: ${chalk_1.default.green(`${avgCoverage} %`)}`);
    }
    else {
        entries.push('Test coverage: ');
        const totalsStrings = [];
        for (const type of getTestCoverage_1.coverageTypes) {
            const { pct } = testCoverage.summary[type];
            const passed = !coverageThreshold || pct >= coverageThreshold[type];
            const name = `${type[0].toUpperCase()}${type.substring(1)}`;
            totalsStrings.push(`${name}: ${chalk_1.default[passed ? 'green' : 'red'](`${pct} %`)}`);
        }
        entries.push({ text: totalsStrings.join('\n'), indent: 2 });
    }
    return entries;
}
exports.getTestCoverageReport = getTestCoverageReport;
//# sourceMappingURL=getTestCoverageReport.js.map